pub struct ExtendedStatus {
pub player_state: ExtendedPlayerState,
pub media_session_id: Option<i32>,
pub media: Option<Media>,
}Expand description
Status of loading the next media
Fields
player_state: ExtendedPlayerStateDescribes the state of the player.
media_session_id: Option<i32>Unique ID for the playback of this specific session. This ID is set by the receiver at LOAD and can be used to identify a specific instance of a playback. For example, two playbacks of “Wish you were here” within the same session would each have a unique mediaSessionId.
media: Option<Media>Full description of the content that is being played back. Only be returned in a status messages if the Media has changed.